# Grey model
<h1 align="center">
<img src="https://raw.githubusercontent.com/romtance/img/main/202303281221322.png" width="300">
</h1><br>

首先安装： `pip install grey_model`

然后简单调用
```python
import grey_model as gm
gm.window()
```

然后即可在图像窗口下进行简单的Gm(1,1)模型的操作，按照操作指引，可以进行GM plus ARIMA的修正模型。

GM系列的模型我在未来进行更新，相信会是一年以后吧，尽情期待。


---
2023-11-26 我回来了，我要继续完成我的包了！！！！